@@ -40,7 +40,7 @@ import sys
 import traceback
 
 from envstack import __version__, config
-from envstack.env import build_sources, expandvars, load_environ, trace_var
+from envstack.env import build_sources, expandvars, export, load_environ, trace_var
 from envstack.wrapper import run_command
 
 
@@ -75,6 +75,11 @@ def parse_args():
         default=config.DEFAULT_NAMESPACE,
         help="the environment stack to use (default '%s')" % config.DEFAULT_NAMESPACE,
     )
+    parser.add_argument(
+        "--export",
+        action="store_true",
+        help="generate export commands for the current shell",
+    )
     parser.add_argument(
         "-p",
         "--platform",
@@ -123,6 +128,8 @@ def main():
             sources = build_sources(args.namespace)
             for source in sources:
                 print(source)
+        elif args.export:
+            print(export(args.namespace, config.SHELL))
         elif command:
             return run_command(args.namespace, command)
         else:
