@@ -37,20 +37,41 @@ import os
 import platform
 import sys
 
+
+def detect_shell():
+    """Detect the current shell."""
+    if PLATFORM == "windows":
+        comspec = os.environ.get("ComSpec")
+        if comspec:
+            if "cmd.exe" in comspec:
+                return "cmd"
+            elif "powershell.exe" in comspec:
+                return "pwsh"
+        else:
+            return "unknown"
+    else:
+        shell = os.environ.get("SHELL")
+        if shell:
+            return shell.split("/")[-1]
+        else:
+            return "unknown"
+
+
 DEBUG = os.getenv("DEBUG")
-DEFAULT_NAMESPACE = "stack"
+DEFAULT_NAMESPACE = os.getenv("DEFAULT_ENV_STACK", "stack")
 LOG_LEVEL = int(os.environ.get("LOG_LEVEL", 20))
 ON_POSIX = "posix" in sys.builtin_module_names
 PLATFORM = platform.system().lower()
 PYTHON_VERSION = sys.version_info[0]
+SHELL = detect_shell()
 USERNAME = os.getenv("USERNAME", os.getenv("USER"))
 
-# default location of the global environment directory by platform
+# default location of the global env stacks
 DEFAULT_ENV_DIR = os.getenv(
     "DEFAULT_ENV_DIR",
     {
-        "darwin": f"/etc/{DEFAULT_NAMESPACE}",
-        "linux": f"/etc/{DEFAULT_NAMESPACE}",
-        "windows": f"C:/ProgramData/{DEFAULT_NAMESPACE}",
+        "darwin": "/etc/envstack",
+        "linux": "/etc/envstack",
+        "windows": "C:/ProgramData/envstack",
     }.get(PLATFORM),
 )
