@@ -356,31 +356,44 @@ def clear_file_cache():
     load_file_cache = {}
 
 
-def safe_eval(value):
-    """Returns template value preserving original class.
-    Useful for preserving nested values in wrappers.
+def decode_value(value):
+    """Returns a decoded value that's been encoded by a wrapper.
+
+    Decoding encoded environments can be tricky. For example, it must account for path
+    templates that include curly braces, e.g. path templates string like this must be
+    preserved:
+
+        '/path/with/{variable}'
+
+    :param value: wrapper encoded env value
+    :returns: decoded value
     """
+    # TODO: find a better way to encode/decode wrapper envs
+    return (
+        str(value)
+        .replace("'[", "[")
+        .replace("]'", "]")
+        .replace('"[', "[")
+        .replace(']"', "]")
+        .replace('"{"', "{'")
+        .replace('"}"', "'}")
+        .replace("'{'", "{'")
+        .replace("'}'", "'}")
+    )
 
-    from envstack.wrapper import decode_value
 
-    try:
-        from ast import literal_eval
+def encode(env, resolved=True):
+    """Returns environment as a dict with str encoded key/values for passing to
+    wrapper subprocesses.
 
-        eval_func = literal_eval
-    except ImportError:
-        # warning: security issue
-        eval_func = eval
-
-    if type(value) == str:
-        try:
-            return eval_func(value)
-        except Exception:
-            try:
-                return eval_func(decode_value(value))
-            except Exception:
-                return value
-
-    return value
+    :param env: `Env` instance or os.environ.
+    :param resolved: fully resolve values (default=True).
+    :returns: dict with bytestring key/values.
+    """
+    c = lambda v: str(v)
+    if resolved:
+        return dict((c(k), c(expandvars(v, env))) for k, v in env.items())
+    return dict((c(k), c(v)) for k, v in env.items())
 
 
 def build_sources(
@@ -481,6 +494,47 @@ def expandvars(var, env=None, recursive=False):
     return EnvVar(var).expand(env, recursive=recursive)
 
 
+def export(name, shell="bash", resolve=False, scope=None):
+    """Returns environment commands that can be sourced.
+
+       $ source <(envstack --export)
+
+    List of shell names: bash, tcsh, cmd, pwsh
+    (see output of config.detect_shell()).
+
+    :param name: stack namespace
+    :param shell: name of shell (default: bash)
+    :param resolve: resolve values (default: True)
+    :param scope: environment scope (default: cwd)
+    :returns: shell commands as string
+    """
+    env = load_environ(name, scope=scope)
+    expList = list()
+    for k, v in env.items():
+        if resolve:
+            v = expandvars(v, env, recursive=False)
+        if shell == "bash":
+            expList.append('export {0}="{1}"'.format(k, v))
+        elif shell == "tcsh":
+            expList.append('setenv {0}:"{1}"'.format(k, v))
+        elif shell == "cmd":
+            expList.append('set {0}="{1}"'.format(k, v))
+        elif shell == "pwsh":
+            expList.append('$env:{0}="{1}"'.format(k, v))
+    expList.sort()
+    exp = "\n".join(expList)
+    return exp
+
+
+def init(name=config.DEFAULT_NAMESPACE):
+    """Initializes the environment for a given namespace.
+
+    :param name: namespace (basename of env files).
+    """
+    env = load_environ(name)
+    os.environ.update(encode(env))
+
+
 def load_environ(
     name=config.DEFAULT_NAMESPACE,
     sources=None,
@@ -562,6 +616,31 @@ def load_file(path):
     return data
 
 
+def safe_eval(value):
+    """Returns template value preserving original class.
+    Useful for preserving nested values in wrappers.
+    """
+
+    try:
+        from ast import literal_eval
+
+        eval_func = literal_eval
+    except ImportError:
+        # warning: security issue
+        eval_func = eval
+
+    if type(value) == str:
+        try:
+            return eval_func(value)
+        except Exception:
+            try:
+                return eval_func(decode_value(value))
+            except Exception:
+                return value
+
+    return value
+
+
 def trace_var(name, var, scope=None):
     """Traces where a var is getting set for a given name.
 
